Calculating orbits by graph search algorithms. Functions defined here form the complete API.
Calculating orbits by graph search algorithms. Functions defined here form the complete API.
How can we extend an orbit? (extending means adding new elements) The general form of extension is taking a collection (frontier) and an action. By applying the action, we produce a new set of elements. In addition, we also return the remaining unprocessed elements in a vector. This gives control on the extension process. How to extend depends on the answers for the following guiding questions.
How can we extend an orbit? (extending means adding new elements) The general form of extension is taking a collection (frontier) and an action. By applying the action, we produce a new set of elements. In addition, we also return the remaining unprocessed elements in a vector. This gives control on the extension process. How to extend depends on the answers for the following guiding questions. 1. Do we have an operator that produces a set of results, or just a single one? SET-VALUED vs SINGLE-VALUE 2. Do we need the extension happen one-by-one, or is it ok to extend the whole frontline at once? single-step vs bulk 3. Does the extensions happen in parallel or in a single thread?
Computing an orbit exhaustively.
Computing an orbit exhaustively.
Partial orbit stopping at first solution.
Partial orbit stopping at first solution.
Finding all solutions when the graph is guaranteed to be circuit free.
Finding all solutions when the graph is guaranteed to be circuit free.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |